==> qtjambi-webenginecore-6.2.10-sources.jar: io/qt/webengine/core/QWebEngineClientCertificateStore.java <==
package io.qt.webengine.core;


/**
 * <p>In-memory store for client certificates</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html">QWebEngineClientCertificateStore</a></p>
 */
public final class QWebEngineClientCertificateStore extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#add">QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final void add(io.qt.network.QSslCertificate certificate, io.qt.network.QSslKey privateKey){
        add_native_cref_QSslCertificate_cref_QSslKey(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate), QtJambi_LibraryUtilities.internal.checkedNativeId(privateKey));
    }
    
    @io.qt.QtUninvokable
    private native void add_native_cref_QSslCertificate_cref_QSslKey(long __this__nativeId, long certificate, long privateKey);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#certificates">QWebEngineClientCertificateStore::certificates()const</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.network.QSslCertificate> certificates(){
        return certificates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#clear">QWebEngineClientCertificateStore::clear()</a></p>
     */
    @io.qt.QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#remove">QWebEngineClientCertificateStore::remove(QSslCertificate)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final void remove(io.qt.network.QSslCertificate certificate){
        remove_native_cref_QSslCertificate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate));
    }
    
    @io.qt.QtUninvokable
    private native void remove_native_cref_QSslCertificate(long __this__nativeId, long certificate);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineClientCertificateStore(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginecore-6.4.4-sources.jar: io/qt/webengine/core/QWebEngineClientCertificateStore.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>In-memory store for client certificates</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html">QWebEngineClientCertificateStore</a></p>
 */
public final class QWebEngineClientCertificateStore extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#add">QWebEngineClientCertificateStore::add(QSslCertificate,QSslKey)</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final void add(io.qt.network.@NonNull QSslCertificate certificate, io.qt.network.@NonNull QSslKey privateKey){
        add_native_cref_QSslCertificate_cref_QSslKey(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate), QtJambi_LibraryUtilities.internal.checkedNativeId(privateKey));
    }
    
    @QtUninvokable
    private native void add_native_cref_QSslCertificate_cref_QSslKey(long __this__nativeId, long certificate, long privateKey);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#certificates">QWebEngineClientCertificateStore::certificates()const</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificates(){
        return certificates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificates_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#clear">QWebEngineClientCertificateStore::clear()</a></p>
     */
    @QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebengineclientcertificatestore.html#remove">QWebEngineClientCertificateStore::remove(QSslCertificate)</a></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final void remove(io.qt.network.@NonNull QSslCertificate certificate){
        remove_native_cref_QSslCertificate(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(certificate));
    }
    
    @QtUninvokable
    private native void remove_native_cref_QSslCertificate(long __this__nativeId, long certificate);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineClientCertificateStore(QPrivateConstructor p) { super(p); } 
    
}
